kedro.io.LambdaDataSet — Kedro 0.17.6 documentation

# kedro.io.LambdaDataSet

class `kedro.io.` `LambdaDataSet`(load, save, exists=None, release=None)

  `LambdaDataSet` loads and saves data to a data set. It relies on delegating to specific implementation such as csv, sql, etc.

  `LambdaDataSet` class captures Exceptions while performing operations on composed `DataSet` implementations. The composed data set is responsible for providing information on how to resolve the issue when possible. This information should be available through str(error).

  Example:

      from kedro.io import LambdaDataSet
      import pandas as pd

      file_name = "test.csv"
      def load() -> pd.DataFrame:
          raise FileNotFoundError("'{}' csv file not found."
                                  .format(file_name))
      data_set = LambdaDataSet(load, None)

  Methods

  `exists`() | Checks whether a data set’s output already exists by calling the provided _exists() method.
  `from_config`(name, config[, load_version, …]) | Create a data set instance using the configuration provided.
  `load`() | Loads data by delegation to the provided load method.
  `release`() | Release any cached data.
  `save`(data) | Saves data by delegation to the provided save method.

  `__init__`(load, save, exists=None, release=None)

    Creates a new instance of `LambdaDataSet` with references to the required input/output data set methods.

    Parameters

      - load (`Optional`[`Callable`[[], `Any`]]) – Method to load data from a data set.

      - save (`Optional`[`Callable`[[`Any`], `None`]]) – Method to save data to a data set.

      - exists (`Optional`[`Callable`[[], `bool`]]) – Method to check whether output data already exists.

      - release (`Optional`[`Callable`[[], `None`]]) – Method to release any cached information.

    Raises

      DataSetError – If a method is specified, but is not a Callable.

  `exists`()

    Checks whether a data set’s output already exists by calling the provided _exists() method.

    Return type

      `bool`

    Returns

      Flag indicating whether the output already exists.

    Raises

      DataSetError – when underlying exists method raises error.

  classmethod `from_config`(name, config, load_version=None, save_version=None)

    Create a data set instance using the configuration provided.

    Parameters

      - name (`str`) – Data set name.

      - config (`Dict`[`str`, `Any`]) – Data set config dictionary.

      - load_version (`Optional`[`str`]) – Version string to be used for `load` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

      - save_version (`Optional`[`str`]) – Version string to be used for `save` operation if the data set is versioned. Has no effect on the data set if versioning was not enabled.

    Return type

      `AbstractDataSet`

    Returns

      An instance of an `AbstractDataSet` subclass.

    Raises

      DataSetError – When the function fails to create the data set from its config.

  `load`()

    Loads data by delegation to the provided load method.

    Return type

      `Any`

    Returns

      Data returned by the provided load method.

    Raises

      DataSetError – When underlying load method raises error.

  `release`()

    Release any cached data.

    Raises

      DataSetError – when underlying release method raises error.

    Return type

      `None`

  `save`(data)

    Saves data by delegation to the provided save method.

    Parameters

      data (`Any`) – the value to be saved by provided save method.

    Raises

      - DataSetError – when underlying save method raises error.

      - FileNotFoundError – when save method got file instead of dir, on Windows.

      - NotADirectoryError – when save method got file instead of dir, on Unix.

    Return type

      `None`